@@ -35,6 +35,8 @@ _policy_fields = set([
     'persistentNotifyUrl',  # 持久化处理结果通知URL
     'persistentPipeline',   # 持久化处理独享队列
     'deleteAfterDays',      # 文件多少天后自动删除
+    'fileType',             # 文件的存储类型，0为普通存储，1为低频存储
+    'isPrefixalScope'       # 指定上传文件必须使用的前缀
 ])
 
 
@@ -139,7 +141,7 @@ class Auth(object):
 
         scope = bucket
         if key is not None:
-            scope = '{0}:{1}'.format(bucket, key)
+            scope = u'{0}:{1}'.format(bucket, key)
 
         args = dict(
             scope=scope,
